Class: Requestsproxy::RequestsproxyReview
- Inherits:
-
Object
- Object
- Requestsproxy::RequestsproxyReview
- Defined in:
- lib/requestsproxy-rest/models/requestsproxy_review.rb
Instance Attribute Summary collapse
-
#comment ⇒ Object
Returns the value of attribute comment.
-
#content ⇒ Object
Returns the value of attribute content.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
-
#external_product_id ⇒ Object
Returns the value of attribute external_product_id.
-
#id ⇒ Object
Returns the value of attribute id.
-
#images_data ⇒ Object
Returns the value of attribute images_data.
-
#product ⇒ Object
Returns the value of attribute product.
-
#product_id ⇒ Object
Returns the value of attribute product_id.
-
#score ⇒ Object
Returns the value of attribute score.
-
#source_review_id ⇒ Object
Returns the value of attribute source_review_id.
-
#title ⇒ Object
Returns the value of attribute title.
-
#user ⇒ Object
Returns the value of attribute user.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
-
#verified_buyer ⇒ Object
Returns the value of attribute verified_buyer.
-
#votes_down ⇒ Object
Returns the value of attribute votes_down.
-
#votes_up ⇒ Object
Returns the value of attribute votes_up.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RequestsproxyReview
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RequestsproxyReview
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 99 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'score') self.score = attributes[:'score'] end if attributes.has_key?(:'votes_up') self.votes_up = attributes[:'votes_up'] end if attributes.has_key?(:'votes_down') self.votes_down = attributes[:'votes_down'] end if attributes.has_key?(:'content') self.content = attributes[:'content'] end if attributes.has_key?(:'title') self.title = attributes[:'title'] end if attributes.has_key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.has_key?(:'verified_buyer') self.verified_buyer = attributes[:'verified_buyer'] end if attributes.has_key?(:'source_review_id') self.source_review_id = attributes[:'source_review_id'] end if attributes.has_key?(:'custom_fields') if (value = attributes[:'custom_fields']).is_a?(Hash) self.custom_fields = value end end if attributes.has_key?(:'images_data') if (value = attributes[:'images_data']).is_a?(Array) self.images_data = value end end if attributes.has_key?(:'user') self.user = attributes[:'user'] end if attributes.has_key?(:'product') self.product = attributes[:'product'] end if attributes.has_key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.has_key?(:'product_id') self.product_id = attributes[:'product_id'] end if attributes.has_key?(:'comment') self.comment = attributes[:'comment'] end if attributes.has_key?(:'external_product_id') self.external_product_id = attributes[:'external_product_id'] end end |
Instance Attribute Details
#comment ⇒ Object
Returns the value of attribute comment.
47 48 49 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 47 def comment @comment end |
#content ⇒ Object
Returns the value of attribute content.
25 26 27 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 25 def content @content end |
#created_at ⇒ Object
Returns the value of attribute created_at.
29 30 31 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 29 def created_at @created_at end |
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
35 36 37 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 35 def custom_fields @custom_fields end |
#external_product_id ⇒ Object
Returns the value of attribute external_product_id.
49 50 51 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 49 def external_product_id @external_product_id end |
#id ⇒ Object
Returns the value of attribute id.
17 18 19 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 17 def id @id end |
#images_data ⇒ Object
Returns the value of attribute images_data.
37 38 39 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 37 def images_data @images_data end |
#product ⇒ Object
Returns the value of attribute product.
41 42 43 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 41 def product @product end |
#product_id ⇒ Object
Returns the value of attribute product_id.
45 46 47 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 45 def product_id @product_id end |
#score ⇒ Object
Returns the value of attribute score.
19 20 21 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 19 def score @score end |
#source_review_id ⇒ Object
Returns the value of attribute source_review_id.
33 34 35 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 33 def source_review_id @source_review_id end |
#title ⇒ Object
Returns the value of attribute title.
27 28 29 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 27 def title @title end |
#user ⇒ Object
Returns the value of attribute user.
39 40 41 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 39 def user @user end |
#user_id ⇒ Object
Returns the value of attribute user_id.
43 44 45 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 43 def user_id @user_id end |
#verified_buyer ⇒ Object
Returns the value of attribute verified_buyer.
31 32 33 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 31 def verified_buyer @verified_buyer end |
#votes_down ⇒ Object
Returns the value of attribute votes_down.
23 24 25 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 23 def votes_down @votes_down end |
#votes_up ⇒ Object
Returns the value of attribute votes_up.
21 22 23 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 21 def votes_up @votes_up end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 52 def self.attribute_map { :'id' => :'id', :'score' => :'score', :'votes_up' => :'votes_up', :'votes_down' => :'votes_down', :'content' => :'content', :'title' => :'title', :'created_at' => :'created_at', :'verified_buyer' => :'verified_buyer', :'source_review_id' => :'source_review_id', :'custom_fields' => :'custom_fields', :'images_data' => :'images_data', :'user' => :'user', :'product' => :'product', :'user_id' => :'user_id', :'product_id' => :'product_id', :'comment' => :'comment', :'external_product_id' => :'external_product_id' } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 75 def self.swagger_types { :'id' => :'String', :'score' => :'Integer', :'votes_up' => :'Integer', :'votes_down' => :'Integer', :'content' => :'String', :'title' => :'String', :'created_at' => :'DateTime', :'verified_buyer' => :'BOOLEAN', :'source_review_id' => :'Integer', :'custom_fields' => :'Hash<String, RequestsproxyReviewCustomField>', :'images_data' => :'Array<RequestsproxyImageData>', :'user' => :'RequestsproxyUserResponse', :'product' => :'RequestsproxyProductResponse', :'user_id' => :'Integer', :'product_id' => :'Integer', :'comment' => :'RequestsproxyComment', :'external_product_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 193 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && score == o.score && votes_up == o.votes_up && votes_down == o.votes_down && content == o.content && title == o.title && created_at == o.created_at && verified_buyer == o.verified_buyer && source_review_id == o.source_review_id && custom_fields == o.custom_fields && images_data == o.images_data && user == o.user && product == o.product && user_id == o.user_id && product_id == o.product_id && comment == o.comment && external_product_id == o.external_product_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 251 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Requestsproxy.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 317 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 230 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
217 218 219 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 217 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
223 224 225 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 223 def hash [id, score, votes_up, votes_down, content, title, created_at, verified_buyer, source_review_id, custom_fields, images_data, user, product, user_id, product_id, comment, external_product_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
180 181 182 183 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 180 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
297 298 299 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 297 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
291 292 293 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 291 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 |
# File 'lib/requestsproxy-rest/models/requestsproxy_review.rb', line 187 def valid? true end |