Class: Requestsproxy::RequestsproxyResponse
- Inherits:
-
Object
- Object
- Requestsproxy::RequestsproxyResponse
- Defined in:
- lib/requestsproxy-rest/models/requestsproxy_response.rb
Instance Attribute Summary collapse
-
#account_star_rating ⇒ Object
Returns the value of attribute account_star_rating.
-
#auth_info ⇒ Object
Returns the value of attribute auth_info.
-
#create_dynamic_coupons ⇒ Object
Returns the value of attribute create_dynamic_coupons.
-
#dynamic_coupons ⇒ Object
Returns the value of attribute dynamic_coupons.
-
#dynamic_coupons_statistics ⇒ Object
Returns the value of attribute dynamic_coupons_statistics.
-
#features ⇒ Object
Returns the value of attribute features.
-
#orders ⇒ Object
Returns the value of attribute orders.
-
#pagination ⇒ Object
Returns the value of attribute pagination.
-
#product ⇒ Object
Returns the value of attribute product.
-
#product_star_rating ⇒ Object
Returns the value of attribute product_star_rating.
-
#products ⇒ Object
Returns the value of attribute products.
-
#products_star_rating ⇒ Object
Returns the value of attribute products_star_rating.
-
#promoted_products ⇒ Object
Returns the value of attribute promoted_products.
-
#review ⇒ Object
Returns the value of attribute review.
-
#reviews ⇒ Object
Returns the value of attribute reviews.
-
#status ⇒ Object
Returns the value of attribute status.
-
#top_reviews ⇒ Object
Returns the value of attribute top_reviews.
-
#user ⇒ Object
Returns the value of attribute user.
-
#webhook ⇒ Object
Returns the value of attribute webhook.
-
#webhook_events ⇒ Object
Returns the value of attribute webhook_events.
-
#webhooks ⇒ Object
Returns the value of attribute webhooks.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RequestsproxyResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RequestsproxyResponse
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'status') self.status = attributes[:'status'] end if attributes.has_key?(:'pagination') self.pagination = attributes[:'pagination'] end if attributes.has_key?(:'reviews') self.reviews = attributes[:'reviews'] end if attributes.has_key?(:'user') self.user = attributes[:'user'] end if attributes.has_key?(:'features') self.features = attributes[:'features'] end if attributes.has_key?(:'orders') self.orders = attributes[:'orders'] end if attributes.has_key?(:'promoted_products') self.promoted_products = attributes[:'promoted_products'] end if attributes.has_key?(:'dynamic_coupons') self.dynamic_coupons = attributes[:'dynamic_coupons'] end if attributes.has_key?(:'dynamic_coupons_statistics') self.dynamic_coupons_statistics = attributes[:'dynamic_coupons_statistics'] end if attributes.has_key?(:'create_dynamic_coupons') self.create_dynamic_coupons = attributes[:'create_dynamic_coupons'] end if attributes.has_key?(:'webhook_events') self.webhook_events = attributes[:'webhook_events'] end if attributes.has_key?(:'webhooks') self.webhooks = attributes[:'webhooks'] end if attributes.has_key?(:'webhook') self.webhook = attributes[:'webhook'] end if attributes.has_key?(:'account_star_rating') self. = attributes[:'account_star_rating'] end if attributes.has_key?(:'product_star_rating') self. = attributes[:'product_star_rating'] end if attributes.has_key?(:'top_reviews') self.top_reviews = attributes[:'top_reviews'] end if attributes.has_key?(:'product') self.product = attributes[:'product'] end if attributes.has_key?(:'products') self.products = attributes[:'products'] end if attributes.has_key?(:'products_star_rating') self. = attributes[:'products_star_rating'] end if attributes.has_key?(:'review') self.review = attributes[:'review'] end if attributes.has_key?(:'auth_info') self.auth_info = attributes[:'auth_info'] end end |
Instance Attribute Details
#account_star_rating ⇒ Object
Returns the value of attribute account_star_rating.
43 44 45 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 43 def @account_star_rating end |
#auth_info ⇒ Object
Returns the value of attribute auth_info.
57 58 59 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 57 def auth_info @auth_info end |
#create_dynamic_coupons ⇒ Object
Returns the value of attribute create_dynamic_coupons.
35 36 37 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 35 def create_dynamic_coupons @create_dynamic_coupons end |
#dynamic_coupons ⇒ Object
Returns the value of attribute dynamic_coupons.
31 32 33 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 31 def dynamic_coupons @dynamic_coupons end |
#dynamic_coupons_statistics ⇒ Object
Returns the value of attribute dynamic_coupons_statistics.
33 34 35 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 33 def dynamic_coupons_statistics @dynamic_coupons_statistics end |
#features ⇒ Object
Returns the value of attribute features.
25 26 27 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 25 def features @features end |
#orders ⇒ Object
Returns the value of attribute orders.
27 28 29 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 27 def orders @orders end |
#pagination ⇒ Object
Returns the value of attribute pagination.
19 20 21 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 19 def pagination @pagination end |
#product ⇒ Object
Returns the value of attribute product.
49 50 51 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 49 def product @product end |
#product_star_rating ⇒ Object
Returns the value of attribute product_star_rating.
45 46 47 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 45 def @product_star_rating end |
#products ⇒ Object
Returns the value of attribute products.
51 52 53 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 51 def products @products end |
#products_star_rating ⇒ Object
Returns the value of attribute products_star_rating.
53 54 55 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 53 def @products_star_rating end |
#promoted_products ⇒ Object
Returns the value of attribute promoted_products.
29 30 31 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 29 def promoted_products @promoted_products end |
#review ⇒ Object
Returns the value of attribute review.
55 56 57 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 55 def review @review end |
#reviews ⇒ Object
Returns the value of attribute reviews.
21 22 23 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 21 def reviews @reviews end |
#status ⇒ Object
Returns the value of attribute status.
17 18 19 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 17 def status @status end |
#top_reviews ⇒ Object
Returns the value of attribute top_reviews.
47 48 49 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 47 def top_reviews @top_reviews end |
#user ⇒ Object
Returns the value of attribute user.
23 24 25 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 23 def user @user end |
#webhook ⇒ Object
Returns the value of attribute webhook.
41 42 43 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 41 def webhook @webhook end |
#webhook_events ⇒ Object
Returns the value of attribute webhook_events.
37 38 39 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 37 def webhook_events @webhook_events end |
#webhooks ⇒ Object
Returns the value of attribute webhooks.
39 40 41 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 39 def webhooks @webhooks end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 60 def self.attribute_map { :'status' => :'status', :'pagination' => :'pagination', :'reviews' => :'reviews', :'user' => :'user', :'features' => :'features', :'orders' => :'orders', :'promoted_products' => :'promoted_products', :'dynamic_coupons' => :'dynamic_coupons', :'dynamic_coupons_statistics' => :'dynamic_coupons_statistics', :'create_dynamic_coupons' => :'create_dynamic_coupons', :'webhook_events' => :'webhook_events', :'webhooks' => :'webhooks', :'webhook' => :'webhook', :'account_star_rating' => :'account_star_rating', :'product_star_rating' => :'product_star_rating', :'top_reviews' => :'top_reviews', :'product' => :'product', :'products' => :'products', :'products_star_rating' => :'products_star_rating', :'review' => :'review', :'auth_info' => :'auth_info' } end |
.swagger_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 87 def self.swagger_types { :'status' => :'RequestsproxyStatus', :'pagination' => :'RequestsproxyPagination', :'reviews' => :'RequestsproxyReviewsResponse', :'user' => :'RequestsproxyUserResponse', :'features' => :'RequestsproxyFeaturesResponse', :'orders' => :'RequestsproxyOrdersResponse', :'promoted_products' => :'RequestsproxyPromotedProductsResponse', :'dynamic_coupons' => :'RequestsproxyDynamicCouponsResponse', :'dynamic_coupons_statistics' => :'RequestsproxyDynamicCouponsStatisticsResponse', :'create_dynamic_coupons' => :'RequestsproxyCreateDynamicCouponsCodesResponse', :'webhook_events' => :'RequestsproxyWebhookEventsResponse', :'webhooks' => :'RequestsproxyWebhooksResponse', :'webhook' => :'RequestsproxyWebhookResponse', :'account_star_rating' => :'RequestsproxyAccountStarRatingResponse', :'product_star_rating' => :'RequestsproxyProductStarRatingResponse', :'top_reviews' => :'RequestsproxyTopReviewsResponse', :'product' => :'RequestsproxyProductResponse', :'products' => :'RequestsproxyProductsResponse', :'products_star_rating' => :'RequestsproxyProductsStarRatingResponse', :'review' => :'RequestsproxyReviewResponse', :'auth_info' => :'RequestsproxyAuthInfoResponse' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 221 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && pagination == o.pagination && reviews == o.reviews && user == o.user && features == o.features && orders == o.orders && promoted_products == o.promoted_products && dynamic_coupons == o.dynamic_coupons && dynamic_coupons_statistics == o.dynamic_coupons_statistics && create_dynamic_coupons == o.create_dynamic_coupons && webhook_events == o.webhook_events && webhooks == o.webhooks && webhook == o.webhook && == o. && == o. && top_reviews == o.top_reviews && product == o.product && products == o.products && == o. && review == o.review && auth_info == o.auth_info end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 283 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Requestsproxy.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 349 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 262 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
249 250 251 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 249 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 255 def hash [status, pagination, reviews, user, features, orders, promoted_products, dynamic_coupons, dynamic_coupons_statistics, create_dynamic_coupons, webhook_events, webhooks, webhook, , , top_reviews, product, products, , review, auth_info].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
208 209 210 211 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 208 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
329 330 331 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 329 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
335 336 337 338 339 340 341 342 343 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 335 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
323 324 325 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 323 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
215 216 217 |
# File 'lib/requestsproxy-rest/models/requestsproxy_response.rb', line 215 def valid? true end |